
#ifndef _C10_kl484_
#define _C10_kl484_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1300_9395(EIF_REFERENCE);
extern void F1300_9396(EIF_REFERENCE);
extern void EIF_Minit484(void);
extern void F733_4212(EIF_REFERENCE);
extern void F733_4213(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
